Tearsheet (generated by QuantStats)

# {{title}}
{{date_range}}

#### {{benchmark_title}} Generated by QuantStats (Lumiwealth Version) (v.{{v}})

Annual Return ⓘ

# {{cagr}}

Total Return ⓘ

## {{total_return}}

Max Drawdown ⓘ

## {{max_drawdown}}

RoMaD ⓘ

## {{romad}}

Longest DD Days ⓘ

## {{longest_dd_days}}

Sharpe ⓘ

## {{sharpe}}

Sortino ⓘ

## {{sortino}}

### Parameters Used

{{parameters_section}}

### Key Performance Metrics

{{metrics}}
{{eoy_title}}
{{eoy_table}}

### Worst 10 Drawdowns

{{dd_info}}
{{returns}}
{{log_returns}}
{{eoy_returns}}
{{monthly_dist}}
{{daily_returns}}
{{rolling_beta}}
{{rolling_vol}}
{{rolling_sharpe}}
{{rolling_sortino}}
{{dd_periods}}
{{dd_plot}}
{{monthly_heatmap}}
{{returns_dist}}
Disclaimer: This report is for informational purposes only and should not be considered as investment advice. Past performance is not indicative of future results.